@@ -2,7 +2,6 @@ import os
 import discord
 import asyncio
 import datetime
-import json
 import aiosqlite
 
 
@@ -601,6 +600,8 @@ class rr():
 
     async def add(payload, dir, client):
         os.chdir(dir)
+        if payload.member.bot:
+            return
         guild = client.get_guild(payload.guild_id)
         db = await aiosqlite.connect("rr.db")
         async with db.execute("SELECT emoji,role FROM rr WHERE guild = ? and msg_id = ?", (str(guild.id),str(payload.message_id))) as cursor:
@@ -615,6 +616,8 @@ class rr():
         os.chdir(dir)
         guild = client.get_guild(payload.guild_id)
         member = guild.get_member(payload.user_id)
+        if member.bot:
+            return
         db = await aiosqlite.connect("rr.db")
         async with db.execute("SELECT emoji,role FROM rr WHERE guild = ? and msg_id = ?", (str(guild.id),str(payload.message_id))) as cursor:
             async for entry in cursor:
@@ -624,20 +627,43 @@ class rr():
                     await member.remove_roles(role)
         await db.close()
 
-    async def clear(message, dir):
+    async def clear_all(ctx, dir):
+        os.chdir(dir)
+        guild = str(ctx.guild.id)
+        db = await aiosqlite.connect("rr.db")
+        await db.execute("DELETE FROM rr WHERE guild = ?", (guild,))
+        await db.commit()
+        await db.close()
+        await ctx.send("Delted all reaction role info for this server.", delete_after=7)
+
+    async def clear_one(ctx, dir, message_id):
+        os.chdir(dir)
+        guild = str(ctx.guild.id)
+        message_id = str(message_id)
+        db = await aiosqlite.connect("rr.db")
+        message_id = message_id.replace(" ", "")
+        message_id = message_id.split(",")
+        for x in message_id:
+            await db.execute("DELETE FROM rr WHERE guild = ? and msg_id = ?", (guild,x))
+        await db.commit()
+        await db.close()
+        message_id = ", ".join(message_id)
+        await ctx.send(f"Delted reaction role info for {message_id}", delete_after=7)
+
+    async def clear_rr(message, dir):
         os.chdir(dir)
-        id = str(message.id)
         guild = str(message.guild.id)
+        id = str(message.id)
         db = await aiosqlite.connect("rr.db")
         async with db.execute("SELECT msg_id FROM rr WHERE guild = ?", (guild,)) as cursor:
             async for entry in cursor:
                 msg_id = entry[0]
-                if id == msg_id:
+                if msg_id == id:
                     await db.execute("DELETE FROM rr WHERE msg_id = ? and guild = ?", (msg_id,guild))
                     await db.commit()
                     return
         await db.close()
-
+        
     async def display(ctx, dir):
         limit = "limit"
         os.chdir(dir)
